@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,12 +30,15 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
 import java.util.Locale;
+import java.util.Optional;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
+import com.openexchange.groupware.userconfiguration.UserPermissionBits;
+import com.openexchange.groupware.userconfiguration.UserPermissionBitsStorage;
 import com.openexchange.java.Collators;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.IndexRange;
@@ -60,6 +63,7 @@ import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.session.Session;
 import com.openexchange.threadpool.ThreadPools;
+import com.openexchange.tools.session.ServerSession;
 import com.openexchange.unifiedinbox.converters.UnifiedInboxFolderConverter;
 import com.openexchange.unifiedinbox.services.Services;
 import com.openexchange.unifiedinbox.utility.LoggingCallable;
@@ -107,7 +111,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         final List<MailAccount> accounts = new ArrayList<MailAccount>(tmp.length);
         final int thisAccountId = unifiedInboxId;
         for (final MailAccount mailAccount : tmp) {
-            if (thisAccountId != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled()) {
+            if (thisAccountId != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled() && !mailAccount.isDeactivated()) {
                 accounts.add(mailAccount);
             }
         }
@@ -600,7 +604,11 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         if (null == fn) {
             return false;
         }
-        final FullnameArgument fa = MailFolderUtility.prepareMailFolderParam(fn);
+        final Optional<FullnameArgument> optFa = MailFolderUtility.optPrepareMailFolderParam(fn);
+        if (!optFa.isPresent()) {
+            return false;
+        }
+        FullnameArgument fa = optFa.get();
         if (!isMailAccountEnabled(fa.getAccountId())) {
             return false;
         }
@@ -626,30 +634,33 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         }
         final String fn = startsWithKnownFullname(fullname);
         if (null != fn) {
-            final FullnameArgument fa = MailFolderUtility.prepareMailFolderParam(fn);
-            final int nestedAccountId = fa.getAccountId();
-            if (!isMailAccountEnabled(nestedAccountId)) {
-                throw UnifiedInboxException.Code.FOLDER_NOT_FOUND.create(fullname);
-            }
-            MailAccess<?, ?> mailAccess = null;
-            try {
-                mailAccess = MailAccess.getInstance(session, nestedAccountId);
-                mailAccess.connect(true, access.isDebug());
-                final String nestedFullname = fa.getFullname();
-                final MailFolder mailFolder = mailAccess.getFolderStorage().getFolder(nestedFullname);
-                final String startingKnownFullname = getStartingKnownFullname(fullname);
-                mailFolder.setFullname(generateNestedFullName(unifiedInboxId, startingKnownFullname, nestedAccountId, nestedFullname));
-                mailFolder.setParentFullname(generateNestedFullName(unifiedInboxId, startingKnownFullname, nestedAccountId, null));
-                mailFolder.setName(getMailAccountName(nestedAccountId));
-                mailFolder.setSubfolders(false);
-                mailFolder.setSubscribedSubfolders(false);
-                mailFolder.setDefaultFolder(false);
-                mailFolder.setDefaultFolderType(DefaultFolderType.NONE);
-                UnifiedInboxFolderConverter.setPermissions(mailFolder, session.getUserId());
-                return mailFolder;
-            } finally {
-                if (null != mailAccess) {
-                    mailAccess.close(true);
+            final Optional<FullnameArgument> optFa = MailFolderUtility.optPrepareMailFolderParam(fn);
+            if (optFa.isPresent()) {
+                FullnameArgument fa = optFa.get();
+                final int nestedAccountId = fa.getAccountId();
+                if (!isMailAccountEnabled(nestedAccountId)) {
+                    throw UnifiedInboxException.Code.FOLDER_NOT_FOUND.create(fullname);
+                }
+                MailAccess<?, ?> mailAccess = null;
+                try {
+                    mailAccess = MailAccess.getInstance(session, nestedAccountId);
+                    mailAccess.connect(true, access.isDebug());
+                    final String nestedFullname = fa.getFullname();
+                    final MailFolder mailFolder = mailAccess.getFolderStorage().getFolder(nestedFullname);
+                    final String startingKnownFullname = getStartingKnownFullname(fullname);
+                    mailFolder.setFullname(generateNestedFullName(unifiedInboxId, startingKnownFullname, nestedAccountId, nestedFullname));
+                    mailFolder.setParentFullname(generateNestedFullName(unifiedInboxId, startingKnownFullname, nestedAccountId, null));
+                    mailFolder.setName(getMailAccountName(nestedAccountId));
+                    mailFolder.setSubfolders(false);
+                    mailFolder.setSubscribedSubfolders(false);
+                    mailFolder.setDefaultFolder(false);
+                    mailFolder.setDefaultFolderType(DefaultFolderType.NONE);
+                    UnifiedInboxFolderConverter.setPermissions(mailFolder, session.getUserId());
+                    return mailFolder;
+                } finally {
+                    if (null != mailAccess) {
+                        mailAccess.close(true);
+                    }
                 }
             }
         }
@@ -666,15 +677,18 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         }
         final String fn = startsWithKnownFullname(parentFullname);
         if (null != fn) {
-            final FullnameArgument fa = MailFolderUtility.prepareMailFolderParam(fn);
-            final int nestedAccountId = fa.getAccountId();
-            if (!isMailAccountEnabled(nestedAccountId)) {
-                throw UnifiedInboxException.Code.FOLDER_NOT_FOUND.create(parentFullname);
+            final Optional<FullnameArgument> optFa = MailFolderUtility.optPrepareMailFolderParam(fn);
+            if (optFa.isPresent()) {
+                FullnameArgument fa = optFa.get();
+                final int nestedAccountId = fa.getAccountId();
+                if (!isMailAccountEnabled(nestedAccountId)) {
+                    throw UnifiedInboxException.Code.FOLDER_NOT_FOUND.create(parentFullname);
+                }
+                /*
+                 * Return empty array since mapped default folders have no subfolders in Unified Mail account
+                 */
+                return EMPTY_PATH;
             }
-            /*
-             * Return empty array since mapped default folders have no subfolders in Unified Mail account
-             */
-            return EMPTY_PATH;
         }
         throw UnifiedInboxException.Code.FOLDER_NOT_FOUND.create(parentFullname);
     }
@@ -694,11 +708,26 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         final int unifiedINBOXAccountId = unifiedInboxId;
         final MailAccount[] accounts;
         {
-            final MailAccountStorageService storageService = Services.getService(MailAccountStorageService.class);
-            final MailAccount[] arr = storageService.getUserMailAccounts(session.getUserId(), session.getContextId());
-            final List<MailAccount> l = new ArrayList<MailAccount>(arr.length);
-            for (final MailAccount mailAccount : arr) {
-                if (unifiedINBOXAccountId != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled()) {
+            UserPermissionBits userPermissionBits;
+            {
+                if (session instanceof ServerSession) {
+                    userPermissionBits = ((ServerSession) session).getUserPermissionBits();
+                } else {
+                    userPermissionBits = UserPermissionBitsStorage.getInstance().getUserPermissionBits(session.getUserId(), session.getContextId());
+                }
+            }
+
+            MailAccountStorageService storageService = Services.getService(MailAccountStorageService.class);
+            MailAccount[] arr;
+            if (userPermissionBits.isMultipleMailAccounts()) {
+                arr = storageService.getUserMailAccounts(session.getUserId(), session.getContextId());
+            } else {
+                arr = storageService.getUserDefaultAndSecondaryMailAccounts(session.getUserId(), session.getContextId());
+            }
+
+            List<MailAccount> l = new ArrayList<MailAccount>(arr.length);
+            for (MailAccount mailAccount : arr) {
+                if (unifiedINBOXAccountId != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled() && !mailAccount.isDeactivated()) {
                     l.add(mailAccount);
                 }
             }
@@ -797,11 +826,25 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
     private MailFolder[] getKnownFolderSubfolders(final String parentFullName) throws OXException {
         final MailAccount[] accounts;
         {
-            final MailAccountStorageService storageService = Services.getService(MailAccountStorageService.class);
-            final MailAccount[] tmp = storageService.getUserMailAccounts(session.getUserId(), session.getContextId());
-            final List<MailAccount> l = new ArrayList<MailAccount>(tmp.length);
-            for (final MailAccount mailAccount : tmp) {
-                if (unifiedInboxId != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled()) {
+            UserPermissionBits userPermissionBits;
+            {
+                if (session instanceof ServerSession) {
+                    userPermissionBits = ((ServerSession) session).getUserPermissionBits();
+                } else {
+                    userPermissionBits = UserPermissionBitsStorage.getInstance().getUserPermissionBits(session.getUserId(), session.getContextId());
+                }
+            }
+
+            MailAccountStorageService storageService = Services.getService(MailAccountStorageService.class);
+            final MailAccount[] tmp;
+            if (userPermissionBits.isMultipleMailAccounts()) {
+                tmp = storageService.getUserMailAccounts(session.getUserId(), session.getContextId());
+            } else {
+                tmp = storageService.getUserDefaultAndSecondaryMailAccounts(session.getUserId(), session.getContextId());
+            }
+            List<MailAccount> l = new ArrayList<MailAccount>(tmp.length);
+            for (MailAccount mailAccount : tmp) {
+                if (unifiedInboxId != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled() && !mailAccount.isDeactivated()) {
                     l.add(mailAccount);
                 }
             }
