@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -77,6 +77,11 @@ public final class UnifiedInboxProperties extends AbstractProtocolProperties imp
         return mailProperties.hideInlineImages();
     }
 
+    @Override
+    public boolean detectInlineImageByDispositionOnly() {
+        return mailProperties.detectInlineImageByDispositionOnly();
+    }
+
     @Override
     public boolean isAllowNestedDefaultFolderOnAltNamespace() {
         return mailProperties.isAllowNestedDefaultFolderOnAltNamespace();
