@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -211,7 +211,7 @@ public final class UnifiedInboxFolderConverter {
             final MailAccount[] arr = storageService.getUserMailAccounts(session.getUserId(), session.getContextId());
             for (int i = 0; !retval && i < arr.length; i++) {
                 final MailAccount mailAccount = arr[i];
-                if (unifiedInboxAccountId != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled()) {
+                if (unifiedInboxAccountId != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled() && !mailAccount.isDeactivated()) {
                     retval = true;
                 }
             }
