@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -1136,6 +1136,26 @@ public final class UnifiedMailMessage extends MailMessage implements Delegatized
         delegatee.removeBccPersonals();
     }
 
+    @Override
+    public void addSender(Collection<InternetAddress> addrs) {
+        delegatee.addSender(addrs);
+    }
+
+    @Override
+    public boolean containsSender() {
+        return delegatee.containsSender();
+    }
+
+    @Override
+    public void removeSender() {
+        delegatee.removeSender();
+    }
+
+    @Override
+    public InternetAddress[] getSender() {
+        return delegatee.getSender();
+    }
+
     @Override
     public InternetAddress[] getAllRecipients() {
         return delegatee.getAllRecipients();
