@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -131,7 +131,8 @@ public final class UnifiedInboxActivator extends HousekeepingActivator {
                             ConfigView view = factory.getView(session.getUserId(), session.getContextId());
                             ComposedConfigProperty<Boolean> property = view.property("com.openexchange.unifiedinbox.enabled", boolean.class);
                             // Either absent or "com.openexchange.unifiedinbox.enabled=true"
-                            return property.isDefined() ? property.get().booleanValue() : true;
+                            Boolean value = property.get();
+                            return value != null ? value.booleanValue() : true;
                         }
 
                         return true;
